# This Langflow integration is for Phoenix Cloud

To add tracing to your Langflow application.
Navigate to the Langflow GitHub repo and pull the project down
Navigate to the repo and create a .env file with all the Arize Phoenix variables.
You can use the .env.example as a template to create the .env file

### Phoenix Env Variables
```bash
# Arize Phoenix Env Variables
PHOENIX_API_KEY="YOUR_PHOENIX_KEY_HERE"
```
